unit QfelLine;

{(C)1997 by Marcin Qfel Zaleski}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs;

type
  TQfelLineStyles = (lsTop,lsBottom,lsLeft,lsRight,lsUp,lsDown);
  TQfelLineStyle  = set of TQfelLineStyles;

  TQfelLine = class(TGraphicControl)
    private
      FStyle : TQfelLineStyle;
      FPen : TPen;
      procedure SetStyle(NewStyle:TQfelLineStyle);
    protected
      procedure Paint; override;
    public
      constructor Create(AOwner:TComponent); override;
      destructor Free;
    published
      procedure PenChange(Sender:TObject);
      property Height;
      property Left;
      property Pen:TPen read FPen write FPen;
      property ShowHint;
      property Style:TQfelLineStyle read FStyle write SetStyle default [lsUp];
      property Top;
      property Width;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('Qfel',[TQfelLine]);
end;

constructor TQfelLine.Create(AOwner:TComponent);
begin
  inherited Create(AOwner);
  FPen := TPen.Create;
  FPen.OnChange := PenChange;
  Height := 40;
  Width := Height;
  Style := [lsUp];
end;

destructor TQfelLine.Free;
begin
  FPen.Free;
  inherited Free;
end;

procedure TQfelLine.Paint;
var
  X : Integer;
  Y : Integer;
  W : Integer;
  H : Integer;
begin
  Canvas.Pen := Pen;
  X := Pen.Width div 2;
  Y := X;
  W := Width - X;
  H := Height - Y;
  if X<Pen.Width/2 then
    begin
      Dec(W);
      Dec(H);
    end;
  if lsTop in FStyle then
    begin
      Canvas.PenPos := Point(X,Y);
      Canvas.LineTo(W,Y);
    end;
  if lsBottom in FStyle then
    begin
      Canvas.PenPos := Point(X,H);
      Canvas.LineTo(W,H);
    end;
  if lsLeft in FStyle then
    begin
      Canvas.PenPos := Point(X,Y);
      Canvas.LineTo(X,H);
    end;
  if lsRight in FStyle then
    begin
      Canvas.PenPos := Point(W,Y);
      Canvas.LineTo(W,H);
    end;
  if lsUp in FStyle then
    begin
      Canvas.PenPos := Point(X,H);
      Canvas.LineTo(W,Y);
    end;
  if lsDown in FStyle then
    begin
       Canvas.PenPos := Point(X,Y);
       Canvas.LineTo(W,H);
    end;
end;

procedure TQfelLine.PenChange(Sender:TObject);
begin
  Invalidate;
end;

procedure TQfelLine.SetStyle(NewStyle:TQfelLineStyle);
begin
  if NewStyle<>FStyle then
    begin
      FStyle := NewStyle;
      Invalidate;
    end;
end;

end.
